(function() {
    'use strict';

    mui.init({
        preloadPages: [{
            url: 'setting.html',
            id: 'setting'
        }, {
            url: 'about.html',
            id: 'about'
        }]
    });

    var txtPwd = document.getElementById('fp-txt-password');
    var txtKey = document.getElementById('fp-txt-key');
    var btnCode = document.getElementById('fp-btn-code');

    // 显示生成密码
    function showCode() {
        if ((txtPwd === null) || (txtKey === null) || (btnCode === null) || (fpSettings === null)) {
            return false;
        }

        var password = txtPwd.value;
        var key = txtKey.value;
        var code = '生成密码(点击复制)';

        if ((password.length < 1) || (key.length < 1)) {
            btnCode.textContent = code;
            return false;
        }

        if (fpSettings.getHasScrambler()) {
            if (fpSettings.getHasCustomPrefix()) {
                key = fpSettings.getCustomPrefix() + key;
            }

            if (fpSettings.getHasCustomSuffix()) {
                key = key + fpSettings.getCustomSuffix();
            }
        }

        if (fpSettings.getHasCustomDigit()) {
            code = fpCode(password, key, fpSettings.getCustomDigit());
        } else {
            code = fpCode(password, key, 16);
        }

        document.getElementById("fp-output-code").value = code;

        if (fpSettings.getHasHideCode()) {
            var len = code.length;
            var part = Math.round(len / 3);
            var mid = len - part * 2;
            btnCode.textContent = code.substr(0, part) + '#'.repeat(mid) + code.substr(-part, part);
        } else {
            btnCode.textContent = code;
        }

        return true;
    }

    // 添加重复字符函数
    String.prototype.repeat = function(num) {
        return new Array(num + 1).join(this);
    }

    if (txtPwd !== null) {
        //txtPwd.addEventListener('change', showCode, false);
        //txtPwd.addEventListener('keydown', showCode, false);
        //txtPwd.addEventListener('blur', showCode, false);
        txtPwd.addEventListener('input', showCode, false);
    }

    var lstKeys = null;

    function createAwesomplete() {
        if (txtKey !== null) {
            lstKeys = new Awesomplete(txtKey, {
                minChars: 3,
                maxItems: 5,
                list: {}
            });
        }
    }

    if (txtKey !== null) {
        //txtKey.addEventListener('change', showCode, false);
        //txtKey.addEventListener('keydown', showCode, false);
        //txtKey.addEventListener('blur', showCode, false);
        txtKey.addEventListener('input', showCode, false);
    }

    if (lstKeys === null) {
        createAwesomplete();
    }

    function updateKeysList() {
        if (lstKeys && fpSettings) {
            lstKeys.list = fpSettings.getKeys();
        }
    }

    mui.plusReady(function() {
        // 隐藏滚动条
        plus.webview.currentWebview().setStyle({
            scrollIndicator: 'none'
        });

        // 关闭键盘
        //document.activeElement.blur();
        // 在应用中获取href传递的值
        //plus.runtime.arguments
        updateKeysList();
    });

    // 首页退出事件
    mui.back = function() {
        mui.confirm('确认退出花密？', '提示', ['确定', '取消'], function(event) {
            if (event.index === 0) {
                if (plus) {
                    plus.runtime.quit();
                }
            }
        });
    };

    // 设置窗口回调函数
    window.addEventListener('refreshKey', function(event) {
        updateKeysList();
        showCode();
    }, false);

    //复制按钮事件
    btnCode.addEventListener('tap', function(event) {
        if (txtPwd === null) {
            txtPwd = document.getElementById('fp-txt-password');
        }
        if (txtKey === null) {
            txtKey = document.getElementById('fp-txt-key');
        }
        if (btnCode === null) {
            btnCode = document.getElementById('fp-btn-code');
        }
        if (lstKeys === null) {
            createAwesomplete();
        }
        if ((mui === null) || (plus === null) || (fpSettings === null)) {
            return false;
        }

        showCode();

        if ((txtPwd.value.length > 0) && (txtKey.value.length > 0)) {
            var code = document.getElementById("fp-output-code").value;

            try {
                if (mui.os.android) {
                    var context = plus.android.importClass('android.content.Context');
                    var main = plus.android.runtimeMainActivity();
                    var clip = main.getSystemService(context.CLIPBOARD_SERVICE);

                    plus.android.invoke(clip, 'setText', code);

                } else if (mui.os.ios) {
                    var UIPasteboard = plus.ios.importClass('UIPasteboard');
                    var generalPasteboard = UIPasteboard.generalPasteboard();
                    // generalPasteboard.setValueforPasteboardType(code, 'public.utf8-plain-text');
                    generalPasteboard.plusCallMethod({
                        setValue: code,
                        forPasteboardType: 'public.utf8-plain-text'
                    });
                } else {
                    plus.nativeUI.toast('复制失败');
                    return false;
                }

            } catch (err) {
                plus.nativeUI.toast(err.message);
            }

            plus.nativeUI.toast('复制成功');

            if (fpSettings.getHasAutoSaveKey()) {
                var key = txtKey.value;
                var keys = fpSettings.getKeys();

                if (keys.indexOf(key) === -1) {
                    keys.push(key);
                    lstKeys.list = keys;
                    fpSettings.putKeys(keys);
                }
            }
        }

        //event.stopPropagation();
    }, false);

    function inputBlur() {
        if (txtPwd !== null) {
            txtPwd.blur();
        }

        if (txtKey !== null) {
            txtKey.blur();
        }
    }

    // 右上角设置按钮点击事件
    document.getElementById('fp-setting').addEventListener('tap', function(event) {
        inputBlur();

        mui.openWindow({
            url: 'setting.html',
            id: 'setting',
            show: {
                aniShow: 'slide-in-right',
                duration: 200
            },
            waiting: {
                autoShow: true,
                title: '正在加载...'
            }
        });

        if (plus) {
            var setting = plus.webview.getWebviewById('setting');
            if (setting) {
                mui.fire(setting, 'refreshKeyCount', {});
            }
        }
        //event.stopPropagation();
    }, false);

    // 重置按钮点击事件
    document.getElementById('fp-undo').addEventListener('tap', function(event) {
        txtPwd.value = '';
        txtKey.value = '';
        showCode();
        plus.nativeUI.toast('清空成功');
        //event.stopPropagation();
    }, false);

    // 关于按钮点击事件
    document.getElementById('fp-about').addEventListener('tap', function(event) {
        inputBlur();

        mui.openWindow({
            url: 'about.html',
            id: 'about',
            show: {
                aniShow: 'slide-in-left',
                duration: 200
            },
            waiting: {
                autoShow: true,
                title: '正在加载...'
            }
        });
        //event.stopPropagation();
    }, false);

}());
