(function() {
    'use strict';

    mui.init({
        beforeback: function() {
            if (plus) {
                var launch = plus.webview.getLaunchWebview();
                if (launch) {
                    mui.fire(launch, 'refreshKey', {});
                }
            }
            return true;
        },
        preloadPages: [{
            url: 'key.html',
            id: 'key'
        }, {
            url: 'import.html',
            id: 'import'
        }, {
            url: 'author.html',
            id: 'author'
        }]
    });

    function refreshKeyCountShow() {
        if (document) {
            var count = document.getElementById('fp-edit-key-count');
            if (count && fpSettings) {
                count.textContent = fpSettings.getKeyCount();
            }

            setTimeout(function () {
                var setting = plus.webview.getWebviewById('key-sub');
                if (setting) {
                    mui.fire(setting, 'clearKeyList', {});
                }
            }, 100);
        }
    }

    // 设置窗口回调函数
    window.addEventListener('refreshKeyCount', refreshKeyCountShow, false);

    function showUpdateCell() {
        if (document) {
            if (mui.os.ios) {
                document.getElementById('fp-cell-update').style.display = 'block';
            }
        }
    }

    // 设置窗口回调函数
    window.addEventListener('showUpdate', showUpdateCell, false);

    mui.plusReady(function() {
        // 隐藏滚动条
        plus.webview.currentWebview().setStyle({
            scrollIndicator: 'none'
        });

        if (fpSettings) {
            if (fpSettings.getHasAutoSaveKey()) {
                mui('#fp-swith-autosave-key').switch().toggle();
            }

            if (fpSettings.getHasScrambler()) {
                mui('#fp-switch-custom-scrambler').switch().toggle();
            }

            if (fpSettings.getHasHideCode()) {
                mui('#fp-switch-hide-code').switch().toggle();
            }

            if (fpSettings.getHasCustomDigit()) {
                mui('#fp-swith-custom-digit').switch().toggle();
            }
            document.getElementById('fp-input-custom-digit').selectedIndex = (fpSettings.getCustomDigit() - 6);
        }

        refreshKeyCountShow();

        if (mui.os.ios) {
            document.getElementById('fp-cell-update').style.display = 'none';
        }

        if (plus && document) {
            plus.runtime.getProperty(plus.runtime.appid, function(info) {
                var strVer = '花密: ' + info.version + ' 程序: ' + plus.runtime.version + ' 内核: '+ plus.runtime.innerVersion;
                document.getElementById('fp-version').textContent = strVer;
            });
        }

    });

    //自动保存区分代号
    document.getElementById('fp-setting-autosave-key').addEventListener('tap', function(event) {
        if (event.target.nodeName.toUpperCase().indexOf('DIV') === -1) {
            mui('#fp-swith-autosave-key').switch().toggle();
        }
        //event.stopPropagation();
    }, false);
    document.getElementById('fp-swith-autosave-key').addEventListener('toggle', function(event) {
        var fpEditKey = document.getElementById('fp-setting-edit-key');

        if (fpEditKey && fpSettings) {
            if (event.detail.isActive) {
                fpSettings.putHasAutoSaveKey(true);
                refreshKeyCountShow();
                fpEditKey.style.display = 'block';
            } else {
                fpSettings.putHasAutoSaveKey(false);
                fpEditKey.style.display = 'none';
            }
        }
        //event.stopPropagation();
    }, false);

    //清空区分代号
    document.getElementById('fp-setting-clear-key').addEventListener('tap', function(event) {
        mui.confirm('确认清空所有区分代号？', '提示', ['确定', '取消'], function(event) {
            if (event.index === 0) {
                if (fpSettings && plus) {
                    fpSettings.putKeys();
                    refreshKeyCountShow();
                    plus.nativeUI.toast('清空成功');
                }
            }
        });
        //event.stopPropagation();
    }, false);

    //自动增添附加扰码
    document.getElementById('fp-setting-custom-scrambler').addEventListener('tap', function(event) {
        if (event.target.nodeName.toUpperCase().indexOf('DIV') === -1) {
            mui('#fp-switch-custom-scrambler').switch().toggle();
        }
        //event.stopPropagation();
    }, false);
    document.getElementById('fp-switch-custom-scrambler').addEventListener('toggle', function(event) {
        if (fpSettings) {
            var hasCustomPrefix = fpSettings.getHasCustomPrefix();
            var hasCustomSuffix = fpSettings.getHasCustomSuffix();
            var fpInputPrefix = document.getElementById('fp-input-prefix');
            var fpInputSuffix = document.getElementById('fp-input-suffix');
            var fpCBPrefix = document.getElementById('fp-checkbox-prefix');
            var fpCBSuffix = document.getElementById('fp-checkbox-suffix');
            var fpInputScramblerPrefix = document.getElementById('fp-input-scrambler-prefix');
            var fpInputScramblerSuffix = document.getElementById('fp-input-scrambler-suffix');

            if (hasCustomPrefix) {
                fpCBPrefix.checked = true;
                document.getElementById('fp-input-custom-scrambler-prefix').value = fpSettings.getCustomPrefix();
            } else {
                fpCBPrefix.checked = false;
            }
            if (hasCustomSuffix) {
                fpCBSuffix.checked = true;
                document.getElementById('fp-input-custom-scrambler-suffix').value = fpSettings.getCustomSuffix();
            } else {
                fpCBSuffix.checked = false;
            }

            if (event.detail.isActive) {
                fpSettings.putHasScrambler(true);
                fpInputPrefix.style.display = 'block';
                if (hasCustomPrefix) {
                    fpInputScramblerPrefix.style.display = 'block';
                } else {
                    fpInputScramblerPrefix.style.display = 'none';
                }
                fpInputSuffix.style.display = 'block';
                if (hasCustomSuffix) {
                    fpInputScramblerSuffix.style.display = 'block';
                } else {
                    fpInputScramblerSuffix.style.display = 'none';
                }
            } else {
                fpSettings.putHasScrambler(false);
                fpInputPrefix.style.display = 'none';
                fpInputScramblerPrefix.style.display = 'none';
                fpInputSuffix.style.display = 'none';
                fpInputScramblerSuffix.style.display = 'none';
            }
        }
        //event.stopPropagation();
    }, false);
    document.getElementById('fp-checkbox-prefix').addEventListener('change', function(event) {
        if (fpSettings) {
            var fpInputPrefix = document.getElementById('fp-input-scrambler-prefix');
            if (this.checked) {
                fpSettings.putHasCustomPrefix(true);
                fpInputPrefix.style.display = 'block';
            } else {
                fpSettings.putHasCustomPrefix(false);
                fpInputPrefix.style.display = 'none';
            }
        }
        //event.stopPropagation();
    }, false);
    document.getElementById('fp-input-custom-scrambler-prefix').addEventListener('input', function(event) {
        if (fpSettings) {
            fpSettings.putCustomPrefix(this.value);
        }
        //event.stopPropagation();
    }, false);
    document.getElementById('fp-checkbox-suffix').addEventListener('change', function(event) {
        if (fpSettings) {
            var fpInputSuffix = document.getElementById('fp-input-scrambler-suffix');
            if (this.checked) {
                fpSettings.putHasCustomSuffix(true);
                fpInputSuffix.style.display = 'block';
            } else {
                fpSettings.putHasCustomSuffix(false);
                fpInputSuffix.style.display = 'none';
            }
        }
        //event.stopPropagation();
    }, false);
    document.getElementById('fp-input-custom-scrambler-suffix').addEventListener('input', function(event) {
        if (fpSettings) {
            fpSettings.putCustomSuffix(this.value);
        }
        //event.stopPropagation();
    }, false);

    //隐藏生成密码
    document.getElementById('fp-setting-hide-code').addEventListener('tap', function(event) {
        if (event.target.nodeName.toUpperCase().indexOf('DIV') === -1) {
            mui('#fp-switch-hide-code').switch().toggle();
        }
        //event.stopPropagation();
    }, false);
    document.getElementById('fp-switch-hide-code').addEventListener('toggle', function(event) {
        if (fpSettings) {
            if (event.detail.isActive) {
                fpSettings.putHasHideCode(true);
            } else {
                fpSettings.putHasHideCode(false);
            }
        }
        //event.stopPropagation();
    }, false);

    //自定义生成密码位数
    document.getElementById('fp-setting-custom-digit').addEventListener('tap', function(event) {
        if (event.target.nodeName.toUpperCase().indexOf('DIV') === -1) {
            mui('#fp-swith-custom-digit').switch().toggle();
        }
        //event.stopPropagation();
    }, false);
    document.getElementById('fp-swith-custom-digit').addEventListener('toggle', function(event) {
        var fpInputDigit = document.getElementById('fp-input-digit');

        if (fpInputDigit && fpSettings) {
            if (event.detail.isActive) {
                fpSettings.putHasCustomDigit(true);
                fpInputDigit.style.display = 'block';
            } else {
                fpSettings.putHasCustomDigit(false);
                fpInputDigit.style.display = 'none';
            }
        }
        //event.stopPropagation();
    }, false);
    document.getElementById('fp-input-custom-digit').addEventListener('change', function(event) {
        if (fpSettings) {
            fpSettings.putCustomDigit(this.value);
        }
        //event.stopPropagation();
    }, false);

    // 编辑按钮点击事件
    document.getElementById('fp-setting-edit-key').addEventListener('tap', function(event) {
        mui.openWindow({
            url: 'key.html',
            id: 'key',
            show: {
                aniShow: 'slide-in-right',
                duration: 200
            },
            waiting: {
                autoShow: true,
                title: '正在加载...'
            }
        });

        if (plus) {
            var setting = plus.webview.getWebviewById('key-sub');
            if (setting) {
                mui.fire(setting, 'refreshKeyList', {});
            }
        }
    }, false);

    // 导入按钮点击事件
    document.getElementById('fp-setting-import-key').addEventListener('tap', function(event) {
        mui.openWindow({
            url: 'import.html',
            id: 'import',
            show: {
                aniShow: 'slide-in-right',
                duration: 200
            },
            waiting: {
                autoShow: true,
                title: '正在加载...'
            }
        });
    }, false);

    // 关于按钮点击事件
    document.getElementById('fp-cell-about').addEventListener('tap', function(event) {
        mui.openWindow({
            url: 'about.html',
            id: 'about',
            show: {
                aniShow: 'slide-in-right',
                duration: 200
            },
            waiting: {
                autoShow: true,
                title: '正在加载...'
            }
        });
    }, false);

    // 更新按钮点击事件
    document.getElementById('fp-cell-update').addEventListener('tap', function(event) {
        if (fpUpdate) {
            fpUpdate.checkUpdate();
        }
        //event.stopPropagation();
    }, false);

    // 作者按钮点击事件
    document.getElementById('fp-cell-author').addEventListener('tap', function(event) {
        mui.openWindow({
            url: 'author.html',
            id: 'author',
            show: {
                aniShow: 'slide-in-right',
                duration: 200
            },
            waiting: {
                autoShow: true,
                title: '正在加载...'
            }
        });
    }, false);

}());